@@ -165,6 +165,8 @@ namespace apvlv
 
     double mScrollvalue;
 
+    int mSearchPagenum;
+    char mSearchCmd;
     bool mSearchReverse;
     guint mSearchSelect;
     ApvlvPoses *mSearchResults;
