@@ -422,7 +422,7 @@ namespace apvlv
 
   int ApvlvDoc::yank (int times)
   {
-    char *txt1, *txt2, *txt3;
+    char *txt1 = NULL, *txt2 = NULL, *txt3 = NULL;
 
     gint y1 = mBlanky1, y2 = mBlanky2;
     if (y1 > y2)
@@ -525,6 +525,12 @@ namespace apvlv
 	return subprocess (ct, key);
       }
 
+    int oct = ct;
+    if (ct == 0)
+      {
+	ct++;
+      }
+
     switch (key)
       {
       case GDK_Page_Down:
@@ -607,7 +613,14 @@ namespace apvlv
 	break;
       case 'G':
 	markposition ('\'');
-	showpage (ct - 1);
+	if (oct == 0)
+	  {
+	    showpage (-1);
+	  }
+	else
+	  {
+	    showpage (ct - 1);
+	  }
 	break;
       case 'm':
       case '\'':
@@ -616,12 +629,34 @@ namespace apvlv
 	return NEED_MORE;
 	break;
       case 'n':
-	markposition ('\'');
-	search ("");
+	if (mSearchCmd == SEARCH)
+	  {
+	    markposition ('\'');
+	    search ("");
+	  }
+	else if (mSearchCmd == BACKSEARCH)
+	  {
+	    markposition ('\'');
+	    search ("", true);
+	  }
+	else
+	  {
+	  }
 	break;
       case 'N':
-	markposition ('\'');
-	search ("", true);
+	if (mSearchCmd == SEARCH)
+	  {
+	    markposition ('\'');
+	    search ("", true);
+	  }
+	else if (mSearchCmd == BACKSEARCH)
+	  {
+	    markposition ('\'');
+	    search ("");
+	  }
+	else
+	  {
+	  }
 	break;
       case CTRL ('v'):
       case 'v':
@@ -815,7 +850,7 @@ namespace apvlv
 	if (mCurrentCache1 != NULL)
 	  {
 	    delete mCurrentCache1;
-	    mCurrentCache2 = NULL;
+	    mCurrentCache1 = NULL;
 	  }
 	mCurrentCache1 = new ApvlvDocCache (mFile);
 
@@ -1218,8 +1253,9 @@ namespace apvlv
 
     // same string, but need to search next page
     else
-      if (((mSearchReverse == reverse)
-	   && mSearchSelect == mSearchResults->size () - 1)
+      if ((mSearchPagenum != mPagenum)
+	  || ((mSearchReverse == reverse)
+	      && mSearchSelect == mSearchResults->size () - 1)
 	  || ((mSearchReverse != reverse) && mSearchSelect == 0))
       {
 	debug
@@ -1256,6 +1292,11 @@ namespace apvlv
 	return false;
       }
 
+    if (*str != '\0')
+      {
+	mSearchCmd = reverse ? BACKSEARCH : SEARCH;
+      }
+
     if (!needsearch (str, reverse))
       {
 	return true;
@@ -1283,6 +1324,7 @@ namespace apvlv
 	    if (mSearchResults != NULL)
 	      {
 		showpage ((i + sum) % sum, 0.5);
+		mSearchPagenum = mPagenum;
 		markselection ();
 		return true;
 	      }
